pynrc.reduce.ref\_pixels
========================

.. automodule:: pynrc.reduce.ref_pixels

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      calc_avg_amps
      calc_avg_cols
      calc_col_smooth
      channel_averaging
      channel_smooth_butter
      channel_smooth_fft
      channel_smooth_savgol
      chrem_med
      mask_helper
      ref_filter
      reffix_amps
      reffix_hxrg
      smooth_fft
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      NRC_refs
   
   

   
   
   



